@@ -6,6 +6,7 @@ import pytest
 import tuxsuite.cli
 import tuxsuite.build
 
+
 sample_token = "Q9qMlmkjkIuIGmEAw-Mf53i_qoJ8Z2eGYCmrNx16ZLLQGrXAHRiN2ce5DGlAebOmnJFp9Ggcq9l6quZdDTtrkw"
 sample_url = "https://foo.bar.tuxbuild.com/v1"
 
@@ -1416,3 +1417,18 @@ def test_patch_series_pass(mocker, sample_patch_tgz, tuxsuite_config):
     assert result.exit_code == 0
     assert build.call_count == 1
     assert wait_for_object.call_count == 1
+
+
+def test_build_config(mocker, tuxsuite_config):
+    config = mocker.MagicMock()
+    config.function.return_value = 0
+    mocker.patch.dict("tuxsuite.cli.build_handlers", config=config)
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxsuite.cli.build,
+        [
+            "config",
+            "205Yag6znViIi4oLWFVDxJC4avb",
+        ],
+    )
+    assert result.exit_code == 2
