@@ -21,8 +21,10 @@ import uuid
 from urllib.parse import urlparse
 
 
-# We will poll for status change for an average duration of 240 minutes
-state_timeout = 14400  # 60 * 240
+# We will poll for status change for an average duration of 240 minutes for builds
+build_state_timeout = 14400  # 60 * 240
+# We will poll for status change for an average duration of 300 minutes for tests
+test_state_timeout = 18000  # 60 * 300
 delay_status_update = int(os.getenv("TUXSUITE_DELAY_STATUS_UPDATE", "29")) + 1
 
 
@@ -255,7 +257,7 @@ class Build(HeadersMixin):
         Wait for the build to finish. Whenever the state changes, yielding the
         new state).
 
-        Will timeout after `state_timeout` seconds.
+        Will timeout after `build_state_timeout` seconds.
         """
         attempts = 1
         max_attempts = 3
@@ -289,7 +291,7 @@ class Build(HeadersMixin):
                 cli_color="cyan",
             ),
         }
-        timeout = time.time() + state_timeout
+        timeout = time.time() + build_state_timeout
         previous_state = None
         while True:
             self.get_status()
@@ -328,7 +330,7 @@ class Build(HeadersMixin):
                     )
             elif time.time() >= timeout:
                 raise tuxsuite.exceptions.Timeout(
-                    f"Build timed out after {state_timeout/60} minutes; abandoning"
+                    f"Build timed out after {build_state_timeout/60} minutes; abandoning"
                 )
             elif iterator:
                 yield
@@ -851,7 +853,7 @@ class Test(HeadersMixin):
         Wait for the test to finish. Whenever the state changes, yielding the
         new state).
 
-        Will timeout after `state_timeout` seconds.
+        Will timeout after `test_state_timeout` seconds.
         """
         waiting_states = {
             "waiting": BuildState(
@@ -876,7 +878,7 @@ class Test(HeadersMixin):
                 cli_color="cyan",
             ),
         }
-        timeout = time.time() + state_timeout
+        timeout = time.time() + test_state_timeout
         previous_state = None
         while True:
             self.status = self.get()
@@ -890,7 +892,7 @@ class Test(HeadersMixin):
                     assert 0
             elif time.time() >= timeout:
                 raise tuxsuite.exceptions.Timeout(
-                    f"Test timed out after {state_timeout/60} minutes; abandoning"
+                    f"Test timed out after {test_state_timeout/60} minutes; abandoning"
                 )
             elif iterator:
                 yield
