@@ -60,7 +60,7 @@ def wait_for_object(build_object):
     result = True
     for state in build_object.watch():
         print_state(state)
-        if state.status == "fail" or state.state == "error" and state.final:
+        if state.status in ["error", "fail"] or state.state == "error" and state.final:
             result = False
     return result
 
